@@ -42,15 +42,12 @@ is" without express or implied warranty.
 #include <string.h>
 #include <stdlib.h>
 
-#include "X.h"
-#include "Xproto.h"
 #include "keysym.h"
 #include "screenint.h"
 #include "inputstr.h"
 #include "misc.h"
 #include "scrnintstr.h"
 #include "servermd.h"
-#include "dixstruct.h"
 #include "extnsionst.h"
 
 #include "Agent.h"
@@ -67,10 +64,6 @@ is" without express or implied warranty.
 
 #ifdef XKB
 
-#include "globals.h"
-#include "property.h"
-#include "Init.h"
-
 #include <nx-X11/extensions/XKB.h>
 
 /*
@@ -142,37 +135,6 @@ extern        Status        XkbGetControls(
 #endif
 );
 
-#ifndef XKB_BASE_DIRECTORY
-#define XKB_BASE_DIRECTORY   "/usr/share/X11/xkb"
-#endif
-#ifndef XKB_ALTERNATE_BASE_DIRECTORY
-#define XKB_ALTERNATE_BASE_DIRECTORY   "/usr/X11R6/lib/X11/xkb"
-#endif
-#ifndef XKB_CONFIG_FILE_NX
-#define XKB_CONFIG_FILE_NX   "/etc/nxagent/nxagent.keyboard"
-#endif
-#ifndef XKB_CONFIG_FILE_X2GO
-#define XKB_CONFIG_FILE_X2GO "/etc/x2go/x2goagent.keyboard"
-#endif
-#ifndef XKB_DFLT_RULES_FILE
-#define XKB_DFLT_RULES_FILE  "xfree86"
-#endif
-#ifndef XKB_ALTS_RULES_FILE
-#define XKB_ALTS_RULES_FILE  "xorg"
-#endif
-#ifndef XKB_DFLT_KB_LAYOUT
-#define XKB_DFLT_KB_LAYOUT   "us"
-#endif
-#ifndef XKB_DFLT_KB_MODEL
-#define XKB_DFLT_KB_MODEL    "pc102"
-#endif
-#ifndef XKB_DFLT_KB_VARIANT
-#define XKB_DFLT_KB_VARIANT  NULL
-#endif
-#ifndef XKB_DFLT_KB_OPTIONS
-#define XKB_DFLT_KB_OPTIONS  NULL
-#endif
-
 extern int XkbDfltRepeatDelay;
 extern int XkbDfltRepeatInterval;
 
@@ -199,8 +161,6 @@ XkbWrapperRec nxagentXkbWrapper;
 
 extern char *nxagentKeyboard;
 
-static char *nxagentXkbGetRules(void);
-
 unsigned int nxagentAltMetaMask;
 unsigned int nxagentAltMask;
 unsigned int nxagentMetaMask;
@@ -500,104 +460,6 @@ static int nxagentRestoreKeyboardDeviceData(DeviceIntPtr devBackup, DeviceIntPtr
 
 static int nxagentFreeKeyboardDeviceData(DeviceIntPtr dev);
 
-static void nxagentCheckXkbBaseDirectory(void)
-{
-
-  /*
-   * Set XkbBaseDirectory global
-   * variable appropriately.
-   */
-
-  #ifdef TEST
-  fprintf(stderr, "nxagentCheckXkbBaseDirectory: "
-              "Before calling _NXGetXkbBasePath:\n");
-
-  fprintf(stderr, "nxagentCheckXkbBaseDirectory: "
-              "XkbBaseDirectory variable [%s].\n",
-                  XkbBaseDirectory);
-  #endif
-
-  XkbBaseDirectory = _NXGetXkbBasePath(XkbBaseDirectory);
-
-  #ifdef TEST
-  fprintf(stderr, "nxagentCheckXkbBaseDirectory: "
-              "After calling _NXGetXkbBasePath:\n");
-
-  fprintf(stderr, "nxagentCheckXkbBaseDirectory: "
-              "XkbBaseDirectory variable [%s].\n",
-                  XkbBaseDirectory);
-  #endif
-
-  return;
-}
-
-static char *nxagentXkbGetRules()
-{
-  int ret;
-  char *path;
-  struct stat buf;
-
-  #ifdef TEST
-  fprintf(stderr, "nxagentXkbGetRules: XkbBaseDirectory [%s].\n",
-              XkbBaseDirectory);
-  #endif
-
-  if (-1 == asprintf(&path, "%s/rules/%s", XkbBaseDirectory, XKB_DFLT_RULES_FILE))
-  {
-    FatalError("nxagentXkbGetRules: malloc failed.");
-  }
-
-  #ifdef TEST
-  fprintf(stderr, "nxagentXkbGetRules: checking rules file [%s]\n", path);
-  #endif
-  ret = stat(path, &buf);
-
-  if (ret == 0)
-  {
-    free(path);
-    #ifdef TEST
-    fprintf(stderr, "nxagentXkbGetRules: returning default rules file [%s]\n", XKB_DFLT_RULES_FILE);
-    #endif
-    return XKB_DFLT_RULES_FILE;
-  }
-
-  #ifdef TEST
-  fprintf(stderr, "nxagentXkbGetRules: WARNING! Failed to stat file [%s]: %s.\n", path, strerror(ret));
-  #endif
-
-  free(path);
-  path = NULL;
-
-  if (-1 == asprintf(&path, "%s/rules/%s", XkbBaseDirectory, XKB_ALTS_RULES_FILE))
-  {
-    FatalError("nxagentXkbGetRules: malloc failed.");
-  }
-
-  #ifdef TEST
-  fprintf(stderr, "nxagentXkbGetRules: checking rules file [%s]\n", path);
-  #endif
-  ret = stat(path, &buf);
-
-  if (ret == 0)
-  {
-    free(path);
-    #ifdef TEST
-    fprintf(stderr, "nxagentXkbGetRules: returning alternative rules file [%s]\n", XKB_ALTS_RULES_FILE);
-    #endif
-    return XKB_ALTS_RULES_FILE;
-  }
-
-  #ifdef WARNING
-  fprintf(stderr, "nxagentXkbGetRules: WARNING! Failed to stat file [%s]: %s.\n", path, strerror(ret));
-  #endif
-
-  free(path);
-  #ifdef TEST
-  fprintf(stderr, "nxagentXkbGetRules: returning default rules file [%s]\n", XKB_DFLT_RULES_FILE);
-  #endif
-  return XKB_DFLT_RULES_FILE;
-}
- 
 void nxagentBell(int volume, DeviceIntPtr pDev, void * ctrl, int cls)
 {
   XBell(nxagentDisplay, volume);
@@ -704,11 +566,10 @@ int nxagentKeyboardProc(DeviceIntPtr pDev, int onoff)
   int mapWidth;
   int min_keycode, max_keycode;
   KeySymsRec keySyms;
-  CARD8 modmap[256];
+  CARD8 modmap[MAP_LENGTH];
   int i, j;
   XKeyboardState values;
   char *model = NULL, *layout = NULL;
-  int free_model = 0, free_layout = 0;
   XkbDescPtr xkb = NULL;
 
   switch (onoff)
@@ -765,7 +626,7 @@ N/A
 #ifdef _XSERVER64
       {
         KeySym64 *keymap64;
-        int i, len;
+        int len;
         keymap64 = XGetKeyboardMapping(nxagentDisplay,
                                      min_keycode,
                                      max_keycode - min_keycode + 1,
@@ -807,8 +668,7 @@ N/A
       nxagentCapsMask = 0;
       nxagentNumlockMask = 0;
 
-      for (i = 0; i < 256; i++)
-        modmap[i] = 0;
+      memset(modmap, 0, sizeof(modmap));
       for (j = 0; j < 8; j++)
         for(i = 0; i < modifier_keymap->max_keypermod; i++) {
           CARD8 keycode;
@@ -823,6 +683,7 @@ N/A
           }
         }
       XFreeModifiermap(modifier_keymap);
+      modifier_keymap = NULL;
 
       nxagentCheckRemoteKeycodes();
 
@@ -831,6 +692,18 @@ N/A
       keySyms.mapWidth = mapWidth;
       keySyms.map = keymap;
 
+      if (XkbQueryExtension(nxagentDisplay,
+                            &nxagentXkbInfo.Opcode,
+                            &nxagentXkbInfo.EventBase,
+                            &nxagentXkbInfo.ErrorBase,
+                            &nxagentXkbInfo.MajorVersion,
+                            &nxagentXkbInfo.MinorVersion) == 0)
+      {
+          ErrorF("Unable to initialize XKEYBOARD extension.\n");
+          goto XkbError;
+      }
+
+
 #ifdef XKB
 
       /*
@@ -839,8 +712,6 @@ N/A
        * variable is checked.
        */
 
-      nxagentCheckXkbBaseDirectory();
-
       if (noXkbExtension) {
         #ifdef TEST
         fprintf(stderr, "nxagentKeyboardProc: No XKB extension.\n");
@@ -852,18 +723,6 @@ XkbError:
         fprintf(stderr, "nxagentKeyboardProc: XKB error.\n");
         #endif
 
-        XkbFreeKeyboard(xkb, XkbAllComponentsMask, True);
-        xkb = NULL;
-        if (free_model) 
-        {
-          free_model = 0;
-          free(model);
-        }
-        if (free_layout)
-        {
-          free_layout = 0;
-          free(layout);
-        }
 #endif
         XGetKeyboardControl(nxagentDisplay, &values);
 
@@ -884,13 +743,8 @@ XkbError:
 
 #ifdef XKB
       } else { /* if (noXkbExtension) */
-        FILE *file;
-        XkbConfigRtrnRec config;
-
-        char *nxagentXkbConfigFilePath;
-
         XkbComponentNamesRec names = {0};
-        char *rules, *variants, *options;
+        char *rules = NULL, *variants = NULL, *options = NULL; /* use xkb default */
 
         #ifdef TEST
         fprintf(stderr, "nxagentKeyboardProc: Using XKB extension.\n");
@@ -900,9 +754,6 @@ XkbError:
         fprintf(stderr, "nxagentKeyboardProc: nxagentKeyboard is [%s].\n", nxagentKeyboard ? nxagentKeyboard : "NULL");
         #endif
 
-
-        rules = nxagentXkbGetRules();
-
         /*
           from nxagent changelog:
           2.0.22:
@@ -925,11 +776,8 @@ XkbError:
             goto XkbError;
           }
 
-          free_model = 1;
-	  model = strndup(nxagentKeyboard, i);
-
-          free_layout = 1;
-	  layout = strdup(&nxagentKeyboard[i + 1]);
+          model = strndup(nxagentKeyboard, i);
+          layout = strdup(&nxagentKeyboard[i + 1]);
 
           /*
            * There is no description for pc105 on Solaris.
@@ -958,205 +806,65 @@ XkbError:
         }
         else
         {
-          layout = XKB_DFLT_KB_LAYOUT;
-          model = XKB_DFLT_KB_MODEL;
-
           #ifdef TEST
           fprintf(stderr, "nxagentKeyboardProc: Using default keyboard: model [%s] layout [%s].\n",
                       model, layout);
           #endif
         }
 
-        variants = XKB_DFLT_KB_VARIANT;
-        options = XKB_DFLT_KB_OPTIONS;
-
-        #ifdef TEST
-        fprintf(stderr, "nxagentKeyboardProc: XkbInitialMap (option -xkbmap) is [%s]\n", XkbInitialMap ? XkbInitialMap : "NULL");
-        #endif
-
-        if (XkbInitialMap) {
-          if ((names.keymap = strchr(XkbInitialMap, '/')) != NULL)
-            ++names.keymap;
-          else
-            names.keymap = XkbInitialMap;
-        }
-
         #ifdef TEST
         fprintf(stderr, "nxagentKeyboardProc: Init XKB extension.\n");
         #endif
 
-        if (XkbQueryExtension(nxagentDisplay,
-                              &nxagentXkbInfo.Opcode,
-                              &nxagentXkbInfo.EventBase,
-                              &nxagentXkbInfo.ErrorBase,
-                              &nxagentXkbInfo.MajorVersion,
-                              &nxagentXkbInfo.MinorVersion) == 0)
-        {
-          ErrorF("Unable to initialize XKEYBOARD extension.\n");
-
-          goto XkbError;
-        }
-
         xkb = XkbGetKeyboard(nxagentDisplay, XkbGBN_AllComponentsMask, XkbUseCoreKbd);
 
         nxagentKeycodeConversionSetup();
 
-        if (xkb == NULL || xkb->geom == NULL)
+        if (xkb && xkb->geom)
         {
-          #ifdef TEST
-          fprintf(stderr, "nxagentKeyboardProc: No current keyboard.\n");
-          if (xkb == NULL)
-          {
-            fprintf(stderr, "nxagentKeyboardProc: xkb is null.\n");
-          }
-          else
-          {
-            fprintf(stderr, "nxagentKeyboardProc: xkb->geom is null.\n");
-          }
-          fprintf(stderr, "nxagentKeyboardProc: Going to set rules and init device.\n");
-          #endif
-          #ifdef DEBUG
-          fprintf(stderr, "nxagentKeyboardProc: Going to set rules and init device: "
-                          "[rules='%s',model='%s',layout='%s',variants='%s',options='%s'].\n",
-                          rules, model, layout, variants, options);
-          #endif
-
-          XkbSetRulesDflts(rules, model, layout, variants, options);
-          XkbInitKeyboardDeviceStruct((void *)pDev, &names, &keySyms, modmap,
-                                          nxagentBell, nxagentChangeKeyboardControl);
-
-          if (!nxagentKeyboard || strcmp(nxagentKeyboard, "query") == 0)
-          {
-            goto XkbError;
-          }
-
-          goto XkbEnd;
-        }
-
-        XkbGetControls(nxagentDisplay, XkbAllControlsMask, xkb);
-
-        if (nxagentX2go)
-          nxagentXkbConfigFilePath = strdup(XKB_CONFIG_FILE_X2GO);
-        else
-          nxagentXkbConfigFilePath = strdup(XKB_CONFIG_FILE_NX);
-
-        if (!nxagentXkbConfigFilePath)
-        {
-          FatalError("nxagentKeyboardProc: malloc failed.");
-        }
-
-        #ifdef TEST
-        fprintf(stderr, "nxagentKeyboardProc: nxagentXkbConfigFilePath [%s].\n",
-                    nxagentXkbConfigFilePath);
-        #endif
-
-        if ((file = fopen(nxagentXkbConfigFilePath, "r"))) {
-
-          #ifdef TEST
-          fprintf(stderr, "nxagentKeyboardProc: Going to parse config file.\n");
-          #endif
-
-          if (XkbCFParse(file, XkbCFDflts, xkb, &config) == 0) {
-            ErrorF("Error parsing config file.\n");
-
-            free(nxagentXkbConfigFilePath);
-            nxagentXkbConfigFilePath = NULL;
-
-            fclose(file);
-            goto XkbError;
-          }
-          if (config.rules_file)
-            rules = config.rules_file;
-          if (config.model)
-          {
-            if (free_model)
-            {
-              free_model = 0; 
-              free(model);
-            }
-            model = config.model;
-          }
-          if (config.layout)
-          {
-            if (free_layout)
-            {
-              free_layout = 0;
-              free(layout);
-            }
-            layout = config.layout;
-          }
-          if (config.variant)
-            variants = config.variant;
-          if (config.options)
-            options = config.options;
-
-          free(nxagentXkbConfigFilePath);
-          nxagentXkbConfigFilePath = NULL;
-
-          fclose(file);
+            XkbGetControls(nxagentDisplay, XkbAllControlsMask, xkb);
         }
+#ifdef TEST
         else
         {
-          #ifdef TEST
-          fprintf(stderr, "nxagentKeyboardProc: No config file, going to set rules and init device.\n");
-          #endif
-          #ifdef DEBUG
-          fprintf(stderr, "nxagentKeyboardProc: Going to set rules and init device: "
-                          "[rules='%s',model='%s',layout='%s',variants='%s',options='%s'].\n",
-                          rules, model, layout, variants, options);
-          #endif
-
-          XkbSetRulesDflts(rules, model, layout, variants, options);
-          XkbInitKeyboardDeviceStruct((void *)pDev, &names, &keySyms, modmap,
-                                          nxagentBell, nxagentChangeKeyboardControl);
-
-          free(nxagentXkbConfigFilePath);
-          nxagentXkbConfigFilePath = NULL;
-
-          if (!nxagentKeyboard || strcmp(nxagentKeyboard, "query") == 0)
-          {
-            goto XkbError;
-          }
-
-          goto XkbEnd;
+            fprintf(stderr, "nxagentKeyboardProc: No current keyboard.\n");
         }
+#endif
 
-        #ifdef TEST
-        fprintf(stderr, "nxagentKeyboardProc: Going to set rules and init device.\n");
-        #endif
         #ifdef DEBUG
         fprintf(stderr, "nxagentKeyboardProc: Going to set rules and init device: "
                         "[rules='%s',model='%s',layout='%s',variants='%s',options='%s'].\n",
-                          rules, model, layout, variants, options);
+                        rules, model, layout, variants, options);
         #endif
 
         XkbSetRulesDflts(rules, model, layout, variants, options);
         XkbInitKeyboardDeviceStruct((void *)pDev, &names, &keySyms, modmap,
                                     nxagentBell, nxagentChangeKeyboardControl);
-        XkbDDXChangeControls((void *)pDev, xkb->ctrls, xkb->ctrls);
 
-XkbEnd:
+        if (nxagentKeyboard && strcmp(nxagentKeyboard, "query") == 0)
+        {
+          goto XkbError;
+        }
+
+        if (xkb && xkb->geom)
+        {
+            XkbDDXChangeControls(pDev, xkb->ctrls, xkb->ctrls);
+        }
 
         if (nxagentOption(Shadow) == 1 && pDev && pDev->key)
         {
           NXShadowInitKeymap(&(pDev->key->curKeySyms));
         }
-
-        if (free_model) 
-        {
-          free_model = 0;
-          free(model);
-        }
-
-        if (free_layout)
-        {
-          free_layout = 0;
-          free(layout);
-        }
-
-        XkbFreeKeyboard(xkb, XkbAllComponentsMask, True);
-        xkb = NULL;
       }
+
+      if (xkb)
+      {
+          XkbFreeKeyboard(xkb, XkbAllComponentsMask, True);
+          xkb = NULL;
+      }
+
+      free(model);
+      free(layout);
 #endif
 
       #ifdef WATCH
