@@ -402,7 +402,7 @@ void nxagentDisconnectSession(void)
   nxagentDisconnectAllGCs();
   nxagentDisconnectDisplay();
 
-  nxagentWMIsRunning = 0;
+  nxagentWMIsRunning = False;
 
   #ifdef TEST
   fprintf(stderr, "nxagentDisconnectSession: Disconnection completed. SigHup is [%d]. IoError is [%d].\n",
@@ -626,7 +626,7 @@ Bool nxagentReconnectSession(void)
   if (nxagentResizeDesktopAtStartup || nxagentOption(Rootless) == True || nxagentOption(Xinerama) == True)
   {
     nxagentChangeScreenConfig(0, nxagentOption(RootWidth),
-                                  nxagentOption(RootHeight), 0, 0);
+                                  nxagentOption(RootHeight));
 
     nxagentResizeDesktopAtStartup = False;
   }
